package com.akamai.androidmdt.androidsdkdemo;


import android.content.pm.ActivityInfo;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.support.v4.app.FragmentActivity;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.akamai.ads.AdsComponent;
import com.akamai.ads.IAdsComponentListener;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.ui.listeners.IMediaPlayerControllerListener;
import com.akamai.ui.media.MediaPlayerController;


public class PlayerActivity extends FragmentActivity implements IAdsComponentListener,IMediaPlayerControllerListener{

    private final int COMMAND_PLAYING = 1;
    private final int COMMAND_START_BUFFERING = 3;
    private final int COMMAND_END_BUFFERING = 4;
    private final int COMMAND_UPDATE_POSITION = 5;
    private int lastPosition = 0;
    private boolean mFullScreenMode;


    private final String MEDIA_ASSET_URL = "http://mediapm.edgesuite.net/ovp/content/demo/video/elephants_dream/elephants_dream_768x428_24.0fps_608kbps.mp4";
    private String adsURL = "http://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpost&cmsid=496&vid=short_onecue&correlator=";
    private String licenseKey = "Uwt-blhCmWNTQBmI-4N77sMQGEN37NQrbZgDnaw0hZiZWsr0TYKeEJBMTCGoAr6sXCCpZiQFXrH6A7BEZ4G6Ww==";

    private MediaPlayerController mediaPlayerController;
    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar progressBar;
    private AdsComponent adsComponent;

    private Boolean mWasPlaying = false;
    private int mCurrentPosition = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_player);

        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.view);
        mediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);
        mediaPlayerController.setVisibility(View.INVISIBLE);
        this.configurePlayer();
    }

    public void configurePlayer(){

        mVideoContainer.setMode(VideoPlayerContainer.MODE_NATIVE_BASIC);
        adsComponent = new AdsComponent(this);
        adsComponent.attachToVideoPlayerContainer(mVideoContainer);
        adsComponent.setAdsUrl(adsURL);
        adsComponent.setEventsListener(this);

        mVideoView = mVideoContainer.getVideoPlayer();
        mVideoView.setLicense(licenseKey);

        mVideoView.setProgressBarControl(progressBar);
        adsComponent.setVideoPlayerView(mVideoView);

        mediaPlayerController.setVideoPlayerView(mVideoView);
        mediaPlayerController.setEventsListener(this);

        ((View)mVideoView).setKeepScreenOn(true);
        mVideoView.playUrl(MEDIA_ASSET_URL);
    }

    @Override
    public void onResume(){
        adsComponent.resumeAd();
        if (mWasPlaying) {
            mVideoView.playUrl(MEDIA_ASSET_URL, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    public void onPause(){
           adsComponent.pauseAd();
        if ((mVideoView.isPlaying() || mVideoView.isPaused()) && !adsComponent.isAdStarted())
        {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
            mVideoView.stop();
        }

        super.onPause();
    }


    //code for add event listener function
    @Override
    public void onAdsError(String s) {

    }

    @Override
    public void onPauseContentRequested() {
        mediaPlayerController.setVisibility(View.INVISIBLE);
    }

    @Override
    public void onResumeContentRequested() {
        mediaPlayerController.setVisibility(View.VISIBLE);
    }

    @Override
    public void onAdsLoaded() {

    }

    @Override
    public void onAdsStarted() {

    }

    @Override
    public void onAdsPaused() {

    }

    @Override
    public void onAdsResumed() {

    }

    @Override
    public void onAdsTrackProgress(int i) {
        if(i == IAdsComponentListener.ADS_PROGRESS_COMPLETED)
            adsComponent.setAdsEnabled(false);
    }

    @Override
    public void onButtonClicked(int arg0) {
        if(arg0 == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN){
            setFullScreenMode(!mFullScreenMode);
        }
    }

    private void setFullScreenMode(boolean fullscreen)
    {
        if(fullscreen == mFullScreenMode)
            return;
        mFullScreenMode = fullscreen;
        // Checks the orientation of the screen
        if (fullscreen) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
            mVideoView.setFullScreen(true);
            mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
            mediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);

        } else {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
            mVideoView.setFullScreen(false);
            mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_NONE);
            mediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
        }
    }

}
