package com.akamai.ampdemo;

import android.app.Activity;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

public class MainActivity extends Activity implements DialogInterface.OnCancelListener, IPlayerEventsListener {

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar mProgressBar;
    private Boolean mWasPlaying = false;
    private int mCurrentPosition = 0;
    private final static String LICENSE = "bhga2f25-cCQ0AwbzrYdjJ3KUpqbcOr63Mf3zhcYQYHnqR6id05flsjywVl6ml-g7BDfRdNaatYTybUfwpXGow==";
    private final static String VIDEO_URL =  "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,1280x720_2000,1280x720_3000,.f4v.csmil/master.m3u8";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoContainer.setMode(VideoPlayerContainer.MODE_HARDWARE_ADVANCED);

        mVideoView = mVideoContainer.getVideoPlayer();
        mVideoView.setProgressBarControl(mProgressBar);
        mVideoView.setLicense(LICENSE);
        mVideoView.setFullScreen(true);
        mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
        mVideoView.setLogEnabled(true);

        //SOLA Analytics implementation in AMP:

        //Set the Configuration URL to the SDK
        //mVideoView.setMediaAnalyticsConfigUrl(MEDIA_ANALYTICS_CONFIG_URL);


        //In case custom event are needed.
        //mVideoView.setMediaAnalyticsData("eventName", "Custom event");

        mVideoView.playUrl(VIDEO_URL,mCurrentPosition);
    }


    @Override
    protected void onResume() {
        Log.d("PlayerView", "OnResume");
        if (mWasPlaying) {
            mVideoView.playUrl(VIDEO_URL, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d("PlayerView", "OnPause");
        if (mVideoView.isPlaying() || mVideoView.isPaused()) {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
        }
        mVideoView.stop();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d("PlayerView", "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        switch(iInEventType) {
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_LOADING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FINISHED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_PLAYING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_ERROR:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_POSITION_UPDATE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_END_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH_REQUESTED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FULLSCREEN_MODE_CHANGE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SIZE_CHANGE:
                break;

            default:
                break;
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d("Player", "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED (" + iInEventType + ")");

        return true;
    }

    @Override
    public void onCancel(DialogInterface dialog)
    {
        finish();
    }
}
